@@ -20,12 +20,14 @@
 
 #include <ortp/payloadtype.h>
 #include <ortp/rtpprofile.h>
+#include <ortp/ortp.h>
+#include <ortp/rtcp.h>
 
-char offset127=127; 
-char offset0xD5=(char)0xD5; 
+char offset127=127;
+char offset0xD5=(char)0xD5;
 char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 
-/* 
+/*
  * IMPORTANT : some compiler don't support the tagged-field syntax. Those
  * macros are there to trap the problem This means that if you want to keep
  * portability, payload types must be defined with their fields in the right
@@ -41,7 +43,11 @@ char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 #define NORMAL_BITRATE(val)	.normal_bitrate=(val)
 #define MIME_TYPE(val)		.mime_type=(val)
 #define CHANNELS(val)		.channels=(val)
-#define FMTP(val)		.FMTP=(val)
+#define RECV_FMTP(val)		.recv_fmtp=(val)
+#define SEND_FMTP(val)		.send_fmtp=(val)
+#define NO_AVPF		.avpf={.features=PAYLOAD_TYPE_AVPF_NONE, .trr_interval=0}
+#define AVPF(feat, intv)		.avpf={.features=(feat), .trr_interval=(intv)}
+#define FLAGS(val)		.flags=(val)
 #elif defined(__GNUC__)
 // GCC's legacy tagged syntax (even old versions have it)
 #define TYPE(val)		type: (val)
@@ -52,7 +58,11 @@ char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 #define NORMAL_BITRATE(val)	normal_bitrate: (val)
 #define MIME_TYPE(val)		mime_type: (val)
 #define CHANNELS(val)		channels: (val)
-#define FMTP(val)		FMTP: (val)
+#define RECV_FMTP(val)		recv_fmtp: (val)
+#define SEND_FMTP(val)		send_fmtp: (val)
+#define NO_AVPF		avpf: {features: PAYLOAD_TYPE_AVPF_NONE, trr_interval: 0}
+#define AVPF(feat, intv)		avpf: {features: (feat), trr_interval: (intv)}
+#define FLAGS(val)		flags: (val)
 #else
 // No tagged syntax supported
 #define TYPE(val)		(val)
@@ -63,268 +73,374 @@ char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 #define NORMAL_BITRATE(val)	(val)
 #define MIME_TYPE(val)		(val)
 #define CHANNELS(val)		(val)
-#define FMTP(val)		(val)
+#define RECV_FMTP(val)		(val)
+#define SEND_FMTP(val)		(val)
+#define NO_AVPF		{PAYLOAD_TYPE_AVPF_NONE, 0}
+#define AVPF(feat, intv)		{(feat), FALSE, (intv)}
+#define FLAGS(val)		(val)
 
 #endif
 
 PayloadType payload_type_pcmu8000={
-	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
-	CLOCK_RATE( 8000),
+	TYPE(PAYLOAD_AUDIO_CONTINUOUS),
+	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(8),
 	ZERO_PATTERN( &offset127),
-	PATTERN_LENGTH( 1),
-	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMU"),
-	CHANNELS(1)
+	PATTERN_LENGTH(1),
+	NORMAL_BITRATE(64000),
+	MIME_TYPE("PCMU"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_pcma8000={
-	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	TYPE(PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(8),
-	ZERO_PATTERN( &offset0xD5),
-	PATTERN_LENGTH( 1),
-	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMA"),
-	CHANNELS(1)
+	ZERO_PATTERN(&offset0xD5),
+	PATTERN_LENGTH(1),
+	NORMAL_BITRATE(64000),
+	MIME_TYPE("PCMA"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_pcm8000={
-	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	TYPE(PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(16),
-	ZERO_PATTERN( offset0),
+	ZERO_PATTERN(offset0),
 	PATTERN_LENGTH(1),
-	NORMAL_BITRATE( 128000),
-	MIME_TYPE ("PCM"),
-	CHANNELS(1)
+	NORMAL_BITRATE(128000),
+	MIME_TYPE("PCM"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_l16_mono={
-	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	TYPE(PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(44100),
 	BITS_PER_SAMPLE(16),
-	ZERO_PATTERN( offset0 ),
+	ZERO_PATTERN(offset0),
 	PATTERN_LENGTH(2),
 	NORMAL_BITRATE(705600),				/* (44100 x 16bits per frame x 1 channel) */
-	MIME_TYPE ("L16"),
-	CHANNELS(1)
+	MIME_TYPE("L16"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_l16_stereo={
-	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	TYPE(PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(44100),
 	BITS_PER_SAMPLE(32),				/* 16bits x 2 channels */
-	ZERO_PATTERN( offset0 ),
+	ZERO_PATTERN(offset0),
 	PATTERN_LENGTH(4),
 	NORMAL_BITRATE(1411200),			/* (44100 x 16bits per frame x 2 channels) */
-	MIME_TYPE ("L16"),
-	CHANNELS(2)
+	MIME_TYPE("L16"),
+	CHANNELS(2),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_lpc1016={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
-	ZERO_PATTERN( NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 2400),
-	MIME_TYPE ("1016"),
-	CHANNELS(1)
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(2400),
+	MIME_TYPE("1016"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 
-PayloadType payload_type_gsm=
-{
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+PayloadType payload_type_gsm={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 13500),
-	MIME_TYPE ("GSM"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(13500),
+	MIME_TYPE("GSM"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
-PayloadType payload_type_lpc=
-{
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+PayloadType payload_type_lpc={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 5600),		/* 20ms / 14 octets per frame */
-	MIME_TYPE ("LPC"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(5600),		/* 20ms / 14 octets per frame */
+	MIME_TYPE("LPC"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
-PayloadType payload_type_g7231=
-{
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+PayloadType payload_type_g7231={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 6300),
-	MIME_TYPE ("G723"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(6300),
+	MIME_TYPE("G723"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
+};
+
+PayloadType payload_type_cn={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(8000),
+	MIME_TYPE("CN"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g729={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G729"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(8000),
+	MIME_TYPE("G729"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g7221={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(16000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 24000),
-	MIME_TYPE ("G7221"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(24000),
+	MIME_TYPE("G7221"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g726_40={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G726-40"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(40000),
+	MIME_TYPE("G726-40"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g726_32={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G726-32"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(32000),
+	MIME_TYPE("G726-32"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g726_24={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G726-24"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(24000),
+	MIME_TYPE("G726-24"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g726_16={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G726-16"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(16000),
+	MIME_TYPE("G726-16"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_aal2_g726_40={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("AAL2-G726-40"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(40000),
+	MIME_TYPE("AAL2-G726-40"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_aal2_g726_32={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("AAL2-G726-32"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(32000),
+	MIME_TYPE("AAL2-G726-32"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_aal2_g726_24={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("AAL2-G726-24"),
-	CHANNELS(1)
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(24000),
+	MIME_TYPE("AAL2-G726-24"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_aal2_g726_16={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
-	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
-	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("AAL2-G726-16"),
-	CHANNELS(1)
-};
-
-PayloadType payload_type_mpv=
-{
-	TYPE( PAYLOAD_VIDEO),
-	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
-	NORMAL_BITRATE( 256000),
-	MIME_TYPE ("MPV"),
-	CHANNELS(0)
+	NORMAL_BITRATE(16000),
+	MIME_TYPE("AAL2-G726-16"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
-
-PayloadType payload_type_h261={
-	TYPE( PAYLOAD_VIDEO),
-	CLOCK_RATE(90000),
-	BITS_PER_SAMPLE(0),
-	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH(0),
-	NORMAL_BITRATE(0),
-	MIME_TYPE ("H261"),
-	CHANNELS(0)
-};
-
-PayloadType payload_type_h263={
-	TYPE( PAYLOAD_VIDEO),
+PayloadType payload_type_mpv={
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263"),
-	CHANNELS(0)
+	MIME_TYPE("MPV"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
-PayloadType payload_type_truespeech=
-{
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
-	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+
+PayloadType payload_type_h261={
+	TYPE(PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE("H261"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
+};
+
+PayloadType payload_type_h263={
+	TYPE(PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE("H263"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
+};
+
+PayloadType payload_type_truespeech={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(8536),
-	MIME_TYPE ("TSP0"),
-	CHANNELS(0)
+	MIME_TYPE("TSP0"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 
@@ -351,66 +467,89 @@ void av_profile_init(RtpProfile *profile)
 	rtp_profile_set_payload(profile,9,&payload_type_g722);
 	rtp_profile_set_payload(profile,10,&payload_type_l16_stereo);
 	rtp_profile_set_payload(profile,11,&payload_type_l16_mono);
+	rtp_profile_set_payload(profile,13,&payload_type_cn);
 	rtp_profile_set_payload(profile,18,&payload_type_g729);
 	rtp_profile_set_payload(profile,31,&payload_type_h261);
 	rtp_profile_set_payload(profile,32,&payload_type_mpv);
 	rtp_profile_set_payload(profile,34,&payload_type_h263);
+	rtp_profile_set_payload(profile,96,&payload_type_t140);
+	rtp_profile_set_payload(profile,97,&payload_type_t140_red);
 }
-	
+
 /* these are extra payload types that can be used dynamically */
 PayloadType payload_type_lpc1015={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(2400),
-	MIME_TYPE ("1015"),
-	CHANNELS(1)
+	MIME_TYPE("1015"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_speex_nb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(8000),   /*not true: 8000 is the minimum*/
-	MIME_TYPE ("speex"),
-	CHANNELS(1)
+	MIME_TYPE("speex"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_speex_wb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(16000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(28000),
-	MIME_TYPE ("speex"),
-	CHANNELS(1)
+	MIME_TYPE("speex"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_speex_uwb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(32000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(28000),
-	MIME_TYPE ("speex"),
-	CHANNELS(1)
+	MIME_TYPE("speex"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_ilbc={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
-	NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */ 
-	MIME_TYPE ("iLBC"),
+	NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */
+	MIME_TYPE("iLBC"),
 	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_amr={
@@ -420,8 +559,12 @@ PayloadType payload_type_amr={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(12200),
-	MIME_TYPE ("AMR"),
-	CHANNELS(1)
+	MIME_TYPE("AMR"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_amrwb={
@@ -431,19 +574,38 @@ PayloadType payload_type_amrwb={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(23850),
-	MIME_TYPE ("AMR-WB"),
+	MIME_TYPE("AMR-WB"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
+};
+
+PayloadType payload_type_gsm_efr={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(12200),
+	MIME_TYPE ("GSM-EFR"),
 	CHANNELS(1)
 };
 
 PayloadType payload_type_mp4v={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("MP4V-ES"),
-	CHANNELS(0)
+	MIME_TYPE("MP4V-ES"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 
@@ -454,8 +616,12 @@ PayloadType payload_type_evrc0={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("EVRC0"),
-	CHANNELS(1)
+	MIME_TYPE("EVRC0"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_evrcb0={
@@ -465,96 +631,132 @@ PayloadType payload_type_evrcb0={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("EVRCB0"),
-	CHANNELS(1)
+	MIME_TYPE("EVRCB0"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
- 
+
 PayloadType payload_type_h263_1998={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263-1998"),
-	CHANNELS(0)
+	MIME_TYPE("H263-1998"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_h263_2000={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("H263-2000"),
-	CHANNELS(0)
+	MIME_TYPE("H263-2000"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_theora={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("theora"),
-	CHANNELS(0)
+	MIME_TYPE("theora"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_h264={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H264"),
-	CHANNELS(0)
+	MIME_TYPE("H264"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	AVPF(PAYLOAD_TYPE_AVPF_FIR | PAYLOAD_TYPE_AVPF_PLI, RTCP_DEFAULT_REPORT_INTERVAL),
+	FLAGS(PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED)
 };
 
 PayloadType payload_type_x_snow={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("x-snow"),
-	CHANNELS(0)
+	MIME_TYPE("x-snow"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_jpeg={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("JPEG"),
-	CHANNELS(0)
+	MIME_TYPE("JPEG"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_vp8={
-	TYPE( PAYLOAD_VIDEO),
+	TYPE(PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("VP8"),
-	CHANNELS(0)
+	MIME_TYPE("VP8"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	AVPF(PAYLOAD_TYPE_AVPF_FIR | PAYLOAD_TYPE_AVPF_PLI | PAYLOAD_TYPE_AVPF_SLI | PAYLOAD_TYPE_AVPF_RPSI, RTCP_DEFAULT_REPORT_INTERVAL),
+	FLAGS(PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED)
 };
 
 PayloadType	payload_type_t140={
-	TYPE( PAYLOAD_TEXT),
+	TYPE(PAYLOAD_TEXT),
 	CLOCK_RATE(1000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("t140"),
-	CHANNELS(0)
+	MIME_TYPE("t140"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_t140_red={
@@ -565,116 +767,219 @@ PayloadType payload_type_t140_red={
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
 	MIME_TYPE("red"),
-	CHANNELS(0)
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType	payload_type_x_udpftp={
-	PAYLOAD_AUDIO_PACKETIZED, /*type */
-	1000,
-	0,
-	NULL,
-	0,
-	0,
-	"x-udpftp",
-	0,
-	0
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(1000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE("x-udpftp"),
+	CHANNELS(0),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_g722={
-       TYPE( PAYLOAD_AUDIO_PACKETIZED),
-       CLOCK_RATE(8000),
-       BITS_PER_SAMPLE( 0),
-       ZERO_PATTERN(NULL),
-       PATTERN_LENGTH( 0),
-       NORMAL_BITRATE( 64000),
-       MIME_TYPE ("G722"),
-       CHANNELS(1)
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(64000),
+	MIME_TYPE("G722"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
 
 PayloadType payload_type_silk_nb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(13000),
-	MIME_TYPE ("SILK"),
-	CHANNELS(1)
+	MIME_TYPE("SILK"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_silk_mb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(12000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(15000),
-	MIME_TYPE ("SILK"),
-	CHANNELS(1)
+	MIME_TYPE("SILK"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_silk_wb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(16000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(20000),
-	MIME_TYPE ("SILK"),
-	CHANNELS(1)
+	MIME_TYPE("SILK"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_silk_swb={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(24000),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(30000),
-	MIME_TYPE ("SILK"),
-	CHANNELS(1)
+	MIME_TYPE("SILK"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
+};
+
+PayloadType payload_type_aaceld_16k={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(24000),
+	MIME_TYPE("mpeg4-generic"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_aaceld_22k={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(22050),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(32000),
-	MIME_TYPE ("mpeg4-generic"),
-	CHANNELS(1)
+	MIME_TYPE("mpeg4-generic"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
+};
+
+PayloadType payload_type_aaceld_32k={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(32000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(48000),
+	MIME_TYPE("mpeg4-generic"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_aaceld_44k={
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(44100),
-	BITS_PER_SAMPLE( 0),
+	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
-	PATTERN_LENGTH( 0),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(64000),
-	MIME_TYPE ("mpeg4-generic"),
-	CHANNELS(1)
+	MIME_TYPE("mpeg4-generic"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
-PayloadType payload_type_opus = {
+PayloadType payload_type_aaceld_48k={
 	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(48000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(64000),
+	MIME_TYPE("mpeg4-generic"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
+};
+
+PayloadType payload_type_opus = {
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(48000), /*mandatory according to RFC*/
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(20000),
 	MIME_TYPE("opus"),
-	CHANNELS(1)
+	CHANNELS(2), /*mandatory according to RFC*/
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
 PayloadType payload_type_isac = {
-	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(16000),
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(32000),
 	MIME_TYPE("iSAC"),
-	CHANNELS(1)
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(PAYLOAD_TYPE_IS_VBR)
+};
+
+PayloadType payload_type_codec2={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(3200),
+	MIME_TYPE("CODEC2"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
 };
