@@ -84,7 +84,7 @@ char * ortp_strdup_vprintf(const char *fmt, va_list ap)
 	/* Guess we need no more than 100 bytes. */
 	int n, size = 200;
 	char *p,*np;
-#ifndef WIN32
+#ifndef _WIN32
 	va_list cap;/*copy of our argument list: a va_list cannot be re-used (SIGSEGV on linux 64 bits)*/
 #endif
 	if ((p = (char *) ortp_malloc (size)) == NULL)
@@ -92,7 +92,7 @@ char * ortp_strdup_vprintf(const char *fmt, va_list ap)
 	while (1)
 	{
 		/* Try to print in the allocated space. */
-#ifndef WIN32
+#ifndef _WIN32
 		va_copy(cap,ap);
 		n = vsnprintf (p, size, fmt, cap);
 		va_end(cap);
@@ -132,9 +132,11 @@ char *ortp_strdup_printf(const char *fmt,...){
 
 char * ortp_strcat_vprintf(char* dst, const char *fmt, va_list ap){
 	char *ret;
-	unsigned long dstlen, retlen;
+	size_t dstlen, retlen;
 
 	ret=ortp_strdup_vprintf(fmt, ap);
+	if (!dst) return ret;
+	
 	dstlen = strlen(dst);
 	retlen = strlen(ret);
 
@@ -158,7 +160,7 @@ char *ortp_strcat_printf(char* dst, const char *fmt,...){
 	return ret;
 }
 
-#if	defined(WIN32) || defined(_WIN32_WCE)
+#if	defined(_WIN32) || defined(_WIN32_WCE)
 #define ENDLINE "\r\n"
 #else
 #define ENDLINE "\n"
@@ -180,7 +182,7 @@ void _ortp_logv_flush(int dummy, ...) {
 	ortp_mutex_unlock(&__log_stored_messages_mutex);
 	for (elem = msglist; elem != NULL; elem = o_list_next(elem)) {
 		ortp_stored_log_t *l = (ortp_stored_log_t *)elem->data;
-#ifdef WIN32
+#ifdef _WIN32
 		ortp_logv_out(l->level, l->msg, empty_va_list);
 #else
 		va_list cap;
@@ -216,7 +218,10 @@ void ortp_logv(int level, const char *fmt, va_list args) {
 		}
 	}
 #if !defined(_WIN32_WCE)
-	if (level == ORTP_FATAL) abort();
+	if (level == ORTP_FATAL) {
+		ortp_logv_flush();
+		abort();
+	}
 #endif
 }
 
@@ -225,14 +230,14 @@ static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args){
 	char *msg;
 	struct timeval tp;
 	struct tm *lt;
-#ifndef WIN32
+#ifndef _WIN32
 	struct tm tmbuf;
 #endif
 	time_t tt;
 	ortp_gettimeofday(&tp,NULL);
 	tt = (time_t)tp.tv_sec;
 
-#ifdef WIN32
+#ifdef _WIN32
 	lt = localtime(&tt);
 #else
 	lt = localtime_r(&tt,&tmbuf);
@@ -265,7 +270,7 @@ static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args){
 		OutputDebugStringA("\r\n");
 	#else
 		{
-			int len=strlen(msg);
+			size_t len=strlen(msg);
 			wchar_t *tmp=(wchar_t*)ortp_malloc0((len+1)*sizeof(wchar_t));
 			mbstowcs(tmp,msg,len);
 			OutputDebugStringW(tmp);
@@ -274,7 +279,9 @@ static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args){
 		}
 	#endif
 #endif
-	fprintf(__log_file,"%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i ortp-%s-%s" ENDLINE,1900+lt->tm_year,1+lt->tm_mon,lt->tm_mday,lt->tm_hour,lt->tm_min,lt->tm_sec,(int)(tp.tv_usec/1000), lname,msg);
+	fprintf(__log_file,"%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i ortp-%s-%s" ENDLINE
+			,1900+lt->tm_year,1+lt->tm_mon,lt->tm_mday,lt->tm_hour,lt->tm_min,lt->tm_sec
+			,(int)(tp.tv_usec/1000), lname,msg);
 	fflush(__log_file);
 	ortp_free(msg);
 }
@@ -290,6 +297,7 @@ static slog2_buffer_t slog2_buffer_handle[2];
 void ortp_qnx_log_handler(const char *domain, OrtpLogLevel lev, const char *fmt, va_list args) {
 	uint8_t severity = SLOG2_DEBUG1;
 	uint8_t buffer_idx = 1;
+	char* msg;
 
 	if (slog2_registered != TRUE) {
 		slog2_buffer_config.buffer_set_name = domain;
@@ -329,6 +337,7 @@ void ortp_qnx_log_handler(const char *domain, OrtpLogLevel lev, const char *fmt,
 			ortp_fatal("Bad level!");
 	}
 
-	vslog2f(slog2_buffer_handle[buffer_idx], 0, severity, fmt, args);
+	msg=ortp_strdup_vprintf(fmt,args);
+	slog2c(slog2_buffer_handle[buffer_idx], 0, severity, msg);
 }
 #endif /* __QNX__ */
