@@ -57,7 +57,7 @@ void ortp_network_simulator_destroy(OrtpNetworkSimulatorCtx *sim){
 	ortp_free(sim);
 }
 
-#ifndef WIN32
+#ifndef _WIN32
 static const char *sched_policy_to_string(int policy){
 	switch(policy){
 		case SCHED_OTHER: return "SCHED_OTHER";
@@ -69,7 +69,7 @@ static const char *sched_policy_to_string(int policy){
 #endif
 
 static void set_high_prio(){
-#ifndef WIN32
+#ifndef _WIN32
 	const char *sched_pref=getenv("ORTP_SIMULATOR_SCHED_POLICY");
 	int policy=SCHED_OTHER;
 	struct sched_param param;
@@ -156,11 +156,11 @@ void rtp_session_enable_network_simulation(RtpSession *session, const OrtpNetwor
 			sim->params.max_buffer_size=sim->params.max_bandwidth;
 			ortp_message("Network simulation: Max buffer size not set for RTP session [%p], using [%i]",session,sim->params.max_buffer_size);
 		}
+		session->net_sim_ctx=sim;
 		if ((params->mode==OrtpNetworkSimulatorOutbound || params->mode==OrtpNetworkSimulatorOutboundControlled) && !sim->thread_started){
 			sim->thread_started=TRUE;
 			ortp_thread_create(&sim->thread, NULL, outboud_simulator_thread, session);
 		}
-		session->net_sim_ctx=sim;
 
 		ortp_message("Network simulation: enabled with the following parameters:\n"
 				"\tlatency=%d\n"
@@ -272,7 +272,7 @@ static mblk_t *simulate_bandwidth_limit_and_jitter(RtpSession *session, mblk_t *
 	/* queue the packet for sending*/
 	if (input){
 		putq(&sim->q,input);
-		bits=(msgdsize(input)+overhead)*8;
+		bits=((int)msgdsize(input)+overhead)*8;
 		sim->qsize+=bits;
 	}
 	/*flow control*/
@@ -280,7 +280,7 @@ static mblk_t *simulate_bandwidth_limit_and_jitter(RtpSession *session, mblk_t *
 		// ortp_message("rtp_session_network_simulate(): discarding packets.");
 		output=getq(&sim->q);
 		if (output){
-			bits=(msgdsize(output)+overhead)*8;
+			bits=((int)msgdsize(output)+overhead)*8;
 			sim->qsize-=bits;
 			sim->drop_by_congestion++;
 			freemsg(output);
@@ -293,7 +293,7 @@ static mblk_t *simulate_bandwidth_limit_and_jitter(RtpSession *session, mblk_t *
 	if (sim->bit_budget>=0){
 		output=getq(&sim->q);
 		if (output){
-			bits=(msgdsize(output)+overhead)*8;
+			bits=((int)msgdsize(output)+overhead)*8;
 			sim->bit_budget-=bits;
 			sim->qsize-=bits;
 		}
