@@ -170,6 +170,30 @@ static mblk_t * make_rtcp_fb_rpsi(RtpSession *session, uint8_t *bit_string, uint
 	return h;
 }
 
+static mblk_t * make_rtcp_fb_generic_nack(RtpSession *session, uint16_t pid, uint16_t blp) {
+	int size = sizeof(rtcp_common_header_t) + sizeof(rtcp_fb_header_t) + sizeof(rtcp_fb_generic_nack_fci_t);
+	mblk_t *h = allocb(size, 0);
+	rtcp_common_header_t *ch;
+	rtcp_fb_header_t *fbh;
+	rtcp_fb_generic_nack_fci_t *fci;
+
+	ch = (rtcp_common_header_t *)h->b_wptr;
+	h->b_wptr += sizeof(rtcp_common_header_t);
+	fbh = (rtcp_fb_header_t *)h->b_wptr;
+	h->b_wptr += sizeof(rtcp_fb_header_t);
+	fci = (rtcp_fb_generic_nack_fci_t *)h->b_wptr;
+	h->b_wptr += sizeof(rtcp_fb_generic_nack_fci_t);
+	fbh->packet_sender_ssrc = htonl(rtp_session_get_send_ssrc(session));
+	fbh->media_source_ssrc = htonl(0);
+	rtcp_fb_generic_nack_fci_set_pid(fci, pid);
+	rtcp_fb_generic_nack_fci_set_blp(fci, blp);
+
+	/* Fill common header */
+	rtcp_common_header_init(ch, session, RTCP_RTPFB, RTCP_RTPFB_NACK, msgdsize(h));
+
+	return h;
+}
+
 static mblk_t * make_rtcp_fb_tmmbr(RtpSession *session, uint64_t mxtbr, uint16_t measured_overhead) {
 	int size = sizeof(rtcp_common_header_t) + sizeof(rtcp_fb_header_t) + sizeof(rtcp_fb_tmmbr_fci_t);
 	mblk_t *h = allocb(size, 0);
@@ -259,6 +283,15 @@ bool_t rtp_session_rtcp_rtpfb_scheduled(RtpSession *session, rtcp_rtpfb_type_t t
 	return FALSE;
 }
 
+void rtp_session_send_rtcp_fb_generic_nack(RtpSession *session, uint16_t pid, uint16_t blp) {
+	mblk_t *m;
+	if ((rtp_session_avpf_enabled(session) == TRUE) && (rtp_session_avpf_feature_enabled(session, ORTP_AVPF_FEATURE_GENERIC_NACK) == TRUE)) {
+		m = make_rtcp_fb_generic_nack(session, pid, blp);
+		rtp_session_add_fb_packet_to_send(session, m);
+		rtp_session_send_fb_rtcp_packet_and_reschedule(session);
+	}
+}
+
 void rtp_session_send_rtcp_fb_pli(RtpSession *session) {
 	mblk_t *m;
 	if ((rtp_session_avpf_enabled(session) == TRUE) && (rtp_session_avpf_payload_type_feature_enabled(session, PAYLOAD_TYPE_AVPF_PLI) == TRUE)) {
@@ -287,11 +320,18 @@ void rtp_session_send_rtcp_fb_fir(RtpSession *session) {
 
 void rtp_session_send_rtcp_fb_sli(RtpSession *session, uint16_t first, uint16_t number, uint8_t picture_id) {
 	mblk_t *m;
-	if ((rtp_session_avpf_enabled(session) == TRUE) && (rtp_session_avpf_payload_type_feature_enabled(session, PAYLOAD_TYPE_AVPF_SLI) == TRUE)) {
-		m = make_rtcp_fb_sli(session, first, number, picture_id);
-		rtp_session_add_fb_packet_to_send(session, m);
-		if (is_fb_packet_to_be_sent_immediately(session) == TRUE) {
-			rtp_session_send_fb_rtcp_packet_and_reschedule(session);
+	if (rtp_session_avpf_enabled(session) == TRUE) {
+		/* Only send SLI if SLI and RPSI features have been enabled. SLI without RPSI is not really useful. */
+		if ((rtp_session_avpf_payload_type_feature_enabled(session, PAYLOAD_TYPE_AVPF_SLI) == TRUE)
+			&& (rtp_session_avpf_payload_type_feature_enabled(session, PAYLOAD_TYPE_AVPF_RPSI) == TRUE)) {
+			m = make_rtcp_fb_sli(session, first, number, picture_id);
+			rtp_session_add_fb_packet_to_send(session, m);
+			if (is_fb_packet_to_be_sent_immediately(session) == TRUE) {
+				rtp_session_send_fb_rtcp_packet_and_reschedule(session);
+			}
+		} else {
+			// Try to fallback to sending a PLI if the SLI feature has not been enabled.
+			rtp_session_send_rtcp_fb_pli(session);
 		}
 	}
 }
@@ -333,12 +373,12 @@ void rtp_session_send_rtcp_fb_tmmbn(RtpSession *session, uint32_t ssrc) {
 }
 
 bool_t rtp_session_avpf_enabled(RtpSession *session) {
-	PayloadType *pt = rtp_profile_get_payload(session->rcv.profile, session->rcv.pt);
+	PayloadType *pt = rtp_profile_get_payload(session->snd.profile, session->snd.pt);
 	return pt && (payload_type_get_flags(pt) & PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED);
 }
 
 bool_t rtp_session_avpf_payload_type_feature_enabled(RtpSession *session, unsigned char feature) {
-	PayloadType *pt = rtp_profile_get_payload(session->rcv.profile, session->rcv.pt);
+	PayloadType *pt = rtp_profile_get_payload(session->snd.profile, session->snd.pt);
 	PayloadTypeAvpfParams params;
 	if (!pt) return FALSE;
 	params = payload_type_get_avpf_params(pt);
