@@ -33,7 +33,7 @@
 #if (_WIN32_WINNT >= 0x0600)
 #include <delayimp.h>
 #undef ExternC /* avoid redefinition... */
-#if WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#ifdef ORTP_WINDOWS_DESKTOP
 #include <QOS2.h>
 #endif
 #endif
@@ -248,7 +248,7 @@ rtp_session_init (RtpSession * session, int mode)
 	rtp_session_set_profile (session, &av_profile); /*the default profile to work with */
 	session->rtp.gs.socket=-1;
 	session->rtcp.gs.socket=-1;
-#ifndef WIN32
+#ifndef _WIN32
 	session->rtp.snd_socket_size=0;	/*use OS default value unless on windows where they are definitely too short*/
 	session->rtp.rcv_socket_size=0;
 #else
@@ -302,6 +302,7 @@ rtp_session_init (RtpSession * session, int mode)
 	rtp_session_set_transports(	session
 								,meta_rtp_transport_new(TRUE,NULL, 0)
 								,meta_rtp_transport_new(FALSE,NULL, 0));
+	session->tev_send_pt = -1; /*check in rtp profile when needed*/
 }
 
 
@@ -705,6 +706,20 @@ int rtp_session_get_send_payload_type(const RtpSession *session){
 	return session->snd.pt;
 }
 
+/**
+ * Assign the payload type number for sending telephone-event.
+ * It is required that a "telephone-event" PayloadType is assigned in the RtpProfile set for the RtpSession.
+ * This function is in most of cases useless, unless there is an ambiguity where several PayloadType for "telephone-event" are present in the RtpProfile.
+ * This might happen during SIP offeranswer scenarios. This function allows to remove any ambiguity by letting the application choose the one to be used.
+ * @param session the RtpSession
+ * @param paytype the payload type number
+ * @returns 0, -1 on error.
+**/
+int rtp_session_set_send_telephone_event_payload_type(RtpSession *session, int paytype){
+	session->tev_send_pt = paytype;
+	return 0;
+}
+
 /**
  *
  *	Sets the expected payload type for incoming packets.
@@ -779,10 +794,10 @@ static void rtp_header_init_from_session(rtp_header_t *rtp, RtpSession *session)
  *@param payload_size size of data carried by the rtp packet.
  *@return a rtp packet in a mblk_t (message block) structure.
 **/
-mblk_t * rtp_session_create_packet(RtpSession *session,int header_size, const uint8_t *payload, int payload_size)
+mblk_t * rtp_session_create_packet(RtpSession *session,size_t header_size, const uint8_t *payload, size_t payload_size)
 {
 	mblk_t *mp;
-	int msglen=header_size+payload_size;
+	size_t msglen=header_size+payload_size;
 	rtp_header_t *rtp;
 
 	mp=allocb(msglen,BPRI_MED);
@@ -801,7 +816,7 @@ mblk_t * rtp_session_create_packet(RtpSession *session,int header_size, const ui
 /**
  * Create a packet already including headers
  */
-mblk_t * rtp_session_create_packet_raw(const uint8_t *packet, int packet_size) {
+mblk_t * rtp_session_create_packet_raw(const uint8_t *packet, size_t packet_size) {
 	mblk_t *mp;
 
 	mp=allocb(packet_size,BPRI_MED);
@@ -828,7 +843,7 @@ mblk_t * rtp_session_create_packet_raw(const uint8_t *packet, int packet_size) {
  * @return: a rtp packet in a mblk_t (message block) structure.
 **/
 
-mblk_t * rtp_session_create_packet_with_data(RtpSession *session, uint8_t *payload, int payload_size, void (*freefn)(void*))
+mblk_t * rtp_session_create_packet_with_data(RtpSession *session, uint8_t *payload, size_t payload_size, void (*freefn)(void*))
 {
 	mblk_t *mp,*mpayload;
 	int header_size=RTP_FIXED_HEADER_SIZE; /* revisit when support for csrc is done */
@@ -860,7 +875,7 @@ mblk_t * rtp_session_create_packet_with_data(RtpSession *session, uint8_t *paylo
  * @param freefn a function that will be called once the buffer is no more needed (the data has been sent).
  * @return a rtp packet in a mblk_t (message block) structure.
 **/
-mblk_t * rtp_session_create_packet_in_place(RtpSession *session,uint8_t *buffer, int size, void (*freefn)(void*) )
+mblk_t * rtp_session_create_packet_in_place(RtpSession *session,uint8_t *buffer, size_t size, void (*freefn)(void*) )
 {
 	mblk_t *mp;
 	rtp_header_t *rtp;
@@ -879,7 +894,7 @@ __rtp_session_sendm_with_ts (RtpSession * session, mblk_t *mp, uint32_t packet_t
 	rtp_header_t *rtp;
 	uint32_t packet_time;
 	int error = 0;
-	int packsize;
+	size_t packsize;
 	RtpScheduler *sched=session->sched;
 	RtpStream *stream=&session->rtp;
 
@@ -942,7 +957,7 @@ __rtp_session_sendm_with_ts (RtpSession * session, mblk_t *mp, uint32_t packet_t
 		}
 		session->rtp.snd_last_ts = packet_ts;
 
-		stream->sent_payload_bytes+=packsize-RTP_FIXED_HEADER_SIZE;
+		stream->sent_payload_bytes+=(uint32_t)(packsize-RTP_FIXED_HEADER_SIZE);
 
 		ortp_global_stats.sent += (1+(int)session->duplication_left) * packsize;
 		stream->stats.sent += (1+(int)session->duplication_left) * packsize;
@@ -1048,6 +1063,26 @@ rtp_session_pick_with_cseq (RtpSession * session, const uint16_t sequence_number
 	return NULL;
 }
 
+static void check_for_seq_number_gap(RtpSession *session, rtp_header_t *rtp) {
+	uint16_t pid;
+	uint16_t i;
+
+	if (RTP_SEQ_IS_STRICTLY_GREATER_THAN(rtp->seq_number, session->rtp.rcv_last_seq + 1)) {
+		uint16_t first_missed_seq = session->rtp.rcv_last_seq + 1;
+		uint16_t diff = rtp->seq_number - first_missed_seq;
+		pid = first_missed_seq;
+		for (i = 0; i <= (diff / 16); i++) {
+			uint16_t seq;
+			uint16_t blp = 0;
+			for (seq = pid + 1; (seq < rtp->seq_number) && ((seq - pid) < 16); seq++) {
+				blp |= (1 << (seq - pid - 1));
+			}
+			rtp_session_send_rtcp_fb_generic_nack(session, pid, blp);
+			pid = seq;
+		}
+	}
+}
+
 /**
  *	Try to get a rtp packet presented as a mblk_t structure from the rtp session.
  *	The @user_ts parameter is relative to the first timestamp of the incoming stream. In other
@@ -1121,10 +1156,10 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	/* check for telephone event first */
 	mp=getq(&session->rtp.tev_rq);
 	if (mp!=NULL){
-		int msgsize=msgdsize(mp);
+		size_t msgsize=msgdsize(mp);
 		ortp_global_stats.recv += msgsize;
 		stream->stats.recv += msgsize;
-		rtp_signal_table_emit2(&session->on_telephone_event_packet,(long)mp);
+		rtp_signal_table_emit2(&session->on_telephone_event_packet,mp);
 		rtp_session_check_telephone_events(session,mp);
 		freemsg(mp);
 		mp=NULL;
@@ -1169,7 +1204,7 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 	end:
 	if (mp != NULL)
 	{
-		int msgsize = msgdsize (mp);	/* evaluate how much bytes (including header) is received by app */
+		size_t msgsize = msgdsize(mp);	/* evaluate how much bytes (including header) is received by app */
 		uint32_t packet_ts;
 		ortp_global_stats.recv += msgsize;
 		stream->stats.recv += msgsize;
@@ -1181,6 +1216,7 @@ rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts)
 		{
 			payload_type_changed_notify(session, rtp->paytype);
 		}
+		check_for_seq_number_gap(session, rtp);
 		/* update the packet's timestamp so that it corrected by the
 		adaptive jitter buffer mechanism */
 		if (session->rtp.jittctl.adaptive){
@@ -1284,7 +1320,7 @@ int rtp_session_recv_with_ts (RtpSession * session, uint8_t * buffer,
 			if (mp!=NULL) rtp_get_payload(mp,&mp->b_rptr);
 		}
 		if (mp){
-			plen=mp->b_wptr-mp->b_rptr;
+			plen=(int)(mp->b_wptr-mp->b_rptr);
 			if (plen<=len){
 				memcpy(buffer,mp->b_rptr,plen);
 				buffer+=plen;
@@ -1379,14 +1415,14 @@ void rtp_session_set_time_jump_limit(RtpSession *session, int milisecs){
 	else session->rtp.ts_jump=ts;
 }
 
-/**
- * Closes the rtp and rtcp sockets.
-**/
-void rtp_session_release_sockets(RtpSession *session){
+void _rtp_session_release_sockets(RtpSession *session, bool_t release_transports){
 	if (session->rtp.gs.socket!=(ortp_socket_t)-1) close_socket (session->rtp.gs.socket);
 	if (session->rtcp.gs.socket!=(ortp_socket_t)-1) close_socket (session->rtcp.gs.socket);
 	session->rtp.gs.socket=-1;
 	session->rtcp.gs.socket=-1;
+	
+	if (!release_transports)
+		return;
 
 	if (session->rtp.gs.tr) {
 		if (session->rtp.gs.tr->t_close)
@@ -1409,6 +1445,13 @@ void rtp_session_release_sockets(RtpSession *session){
 	*/
 }
 
+/**
+ * Closes the rtp and rtcp sockets, and associated RtpTransport.
+**/
+void rtp_session_release_sockets(RtpSession *session){
+	_rtp_session_release_sockets(session, TRUE);
+}
+
 ortp_socket_t rtp_session_get_rtp_socket(const RtpSession *session){
 	return rtp_session_using_transport(session, rtp) ? (session->rtp.gs.tr->t_getsocket)(session->rtp.gs.tr) : session->rtp.gs.socket;
 }
@@ -1494,7 +1537,7 @@ void rtp_session_uninit (RtpSession * session)
 	if (rtcp_meta_transport)
 		meta_rtp_transport_destroy(rtcp_meta_transport);
 
-#if (_WIN32_WINNT >= 0x0600) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#if (_WIN32_WINNT >= 0x0600) && defined(ORTP_WINDOWS_DESKTOP)
 	if (session->rtp.QoSFlowID != 0)
 	{
 		OSVERSIONINFOEX ovi;
@@ -1720,9 +1763,9 @@ static float compute_bw(struct timeval *orig, unsigned int bytes, const struct t
 	float bw;
 	float time;
 	
-	time=(float)(current->tv_sec - orig->tv_sec) +
-		((float)(current->tv_usec - orig->tv_usec)*1e-6);
-	bw=((float)bytes)*8/(time+0.0001);
+	time=(float)((double)(current->tv_sec - orig->tv_sec) +
+		((double)(current->tv_usec - orig->tv_usec)*1e-6));
+	bw=((float)bytes)*8/(time+0.0001f);
 	/*+0.0001 avoids a division by zero without changing the results significatively*/
 	*orig=*current;
 	return bw;
@@ -1861,7 +1904,7 @@ int rtp_get_payload(mblk_t *packet, unsigned char **start){
 			tmp=packet->b_cont->b_rptr+(header_len- (packet->b_wptr-packet->b_rptr));
 			if (tmp<=packet->b_cont->b_wptr){
 				*start=tmp;
-				return packet->b_cont->b_wptr-tmp;
+				return (int)(packet->b_cont->b_wptr-tmp);
 			}
 		}
 		ortp_warning("Invalid RTP packet");
@@ -1874,7 +1917,7 @@ int rtp_get_payload(mblk_t *packet, unsigned char **start){
 		}
 	}
 	*start=tmp;
-	return packet->b_wptr-tmp;
+	return (int)(packet->b_wptr-tmp);
 }
 
 /**
@@ -1935,7 +1978,7 @@ uint32_t rtp_session_time_to_ts(RtpSession *session, int millisecs){
 	if (payload == NULL)
 	{
 		ortp_warning
-			("rtp_session_ts_to_t: use of unsupported payload type %d.", session->snd.pt);
+			("rtp_session_time_to_ts: use of unsupported payload type %d.", session->snd.pt);
 		return 0;
 	}
 	/* the return value is in milisecond */
@@ -2020,7 +2063,8 @@ void meta_rtp_set_session(RtpSession *s,MetaRtpTransportImpl *m){
 }
 
 int meta_rtp_transport_sendto(RtpTransport *t, mblk_t *msg , int flags, const struct sockaddr *to, socklen_t tolen) {
-	int prev_ret,ret;
+	size_t prev_ret;
+	int ret;
 	OList *elem;
 	MetaRtpTransportImpl *m = (MetaRtpTransportImpl*)t->data;
 
@@ -2073,7 +2117,8 @@ int meta_rtp_transport_modifier_inject_packet(const RtpTransport *t, RtpTranspor
  * allow a modifier to inject a packet wich will be treated by successive modifiers
  */
 int meta_rtp_transport_modifier_inject_packet_to(const RtpTransport *t, RtpTransportModifier *tpm, mblk_t *msg , int flags,const struct sockaddr *to, socklen_t tolen) {
-	int prev_ret,ret;
+	size_t prev_ret;
+	int ret;
 	OList *elem;
 	bool_t packetInjected = tpm?FALSE:TRUE; /*if no modifier, start from the begening*/
 	MetaRtpTransportImpl *m = (MetaRtpTransportImpl*)t->data;
