@@ -33,12 +33,12 @@
 #if (_WIN32_WINNT >= 0x0600)
 #include <delayimp.h>
 #undef ExternC
-#if WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#ifdef ORTP_WINDOWS_DESKTOP
 #include <QOS2.h>
 #endif
 #endif
 
-#if (defined(WIN32) || defined(_WIN32_WCE)) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#if (defined(_WIN32) || defined(_WIN32_WCE)) && defined(ORTP_WINDOWS_DESKTOP)
 #include <mswsock.h>
 #endif
 
@@ -49,19 +49,33 @@
 
 #define can_connect(s)	( (s)->use_connect && !(s)->symmetric_rtp)
 
-#if defined(WIN32) || defined(_WIN32_WCE)
+#if defined(_WIN32) || defined(_WIN32_WCE)
 #ifndef WSAID_WSARECVMSG
 /* http://source.winehq.org/git/wine.git/blob/HEAD:/include/mswsock.h */
 #define WSAID_WSARECVMSG {0xf689d7c8,0x6f1f,0x436b,{0x8a,0x53,0xe5,0x4f,0xe3,0x51,0xc3,0x22}}
+#ifndef MAX_NATURAL_ALIGNMENT
 #define MAX_NATURAL_ALIGNMENT sizeof(DWORD)
+#endif
+#ifndef TYPE_ALIGNMENT
 #define TYPE_ALIGNMENT(t) FIELD_OFFSET(struct { char x; t test; },test)
+#endif
 typedef WSACMSGHDR *LPWSACMSGHDR;
+#ifndef WSA_CMSGHDR_ALIGN
 #define WSA_CMSGHDR_ALIGN(length) (((length) + TYPE_ALIGNMENT(WSACMSGHDR)-1) & (~(TYPE_ALIGNMENT(WSACMSGHDR)-1)))
+#endif
+#ifndef WSA_CMSGDATA_ALIGN
 #define WSA_CMSGDATA_ALIGN(length) (((length) + MAX_NATURAL_ALIGNMENT-1) & (~(MAX_NATURAL_ALIGNMENT-1)))
+#endif
+#ifndef WSA_CMSG_FIRSTHDR
 #define WSA_CMSG_FIRSTHDR(msg) (((msg)->Control.len >= sizeof(WSACMSGHDR)) ? (LPWSACMSGHDR)(msg)->Control.buf : (LPWSACMSGHDR)NULL)
+#endif
+#ifndef WSA_CMSG_NXTHDR
 #define WSA_CMSG_NXTHDR(msg,cmsg) ((!(cmsg)) ? WSA_CMSG_FIRSTHDR(msg) : ((((u_char *)(cmsg) + WSA_CMSGHDR_ALIGN((cmsg)->cmsg_len) + sizeof(WSACMSGHDR)) > (u_char *)((msg)->Control.buf) + (msg)->Control.len) ? (LPWSACMSGHDR)NULL : (LPWSACMSGHDR)((u_char *)(cmsg) + WSA_CMSGHDR_ALIGN((cmsg)->cmsg_len))))
+#endif
+#ifndef WSA_CMSG_DATA
 #define WSA_CMSG_DATA(cmsg) ((u_char *)(cmsg) + WSA_CMSGDATA_ALIGN(sizeof(WSACMSGHDR)))
 #endif
+#endif
 #undef CMSG_FIRSTHDR
 #define CMSG_FIRSTHDR WSA_CMSG_FIRSTHDR
 #undef CMSG_NXTHDR
@@ -73,7 +87,7 @@ static LPFN_WSARECVMSG ortp_WSARecvMsg = NULL;
 
 #endif
 
-#if defined(WIN32) || defined(_WIN32_WCE) || defined(__QNX__)
+#if defined(_WIN32) || defined(_WIN32_WCE) || defined(__QNX__)
 /* Mingw32 does not define AI_V4MAPPED, however it is supported starting from Windows Vista. QNX also does not define AI_V4MAPPED. */
 #	ifndef AI_V4MAPPED
 #	define AI_V4MAPPED 0x00000800
@@ -93,7 +107,7 @@ static LPFN_WSARECVMSG ortp_WSARecvMsg = NULL;
 static int
 _rtp_session_set_remote_addr_full (RtpSession * session, const char * rtp_addr, int rtp_port, const char * rtcp_addr, int rtcp_port, bool_t is_aux);
 
-static bool_t try_connect(int fd, const struct sockaddr *dest, socklen_t addrlen){
+static bool_t try_connect(ortp_socket_t fd, const struct sockaddr *dest, socklen_t addrlen){
 	if (connect(fd,dest,addrlen)<0){
 		ortp_warning("Could not connect() socket: %s",getSocketError());
 		return FALSE;
@@ -234,10 +248,10 @@ static ortp_socket_t create_and_bind(const char *addr, int *port, int *sock_fami
 		}
 
 		*sock_family=res->ai_family;
-		err = bind (sock, res->ai_addr, res->ai_addrlen);
+		err = bind(sock, res->ai_addr, (int)res->ai_addrlen);
 		if (err != 0){
 			ortp_error ("Fail to bind rtp socket to (addr=%s port=%i) : %s.", addr, *port, getSocketError());
-			close_socket (sock);
+			close_socket(sock);
 			sock=-1;
 			continue;
 		}
@@ -246,11 +260,11 @@ static ortp_socket_t create_and_bind(const char *addr, int *port, int *sock_fami
 		break;
 	}
 	memcpy(bound_addr,res0->ai_addr,res0->ai_addrlen);
-	*bound_addr_len=res0->ai_addrlen;
+	*bound_addr_len=(socklen_t)res0->ai_addrlen;
 
 	freeaddrinfo(res0);
 
-#if defined(WIN32) || defined(_WIN32_WCE)
+#if defined(_WIN32) || defined(_WIN32_WCE)
 	if (ortp_WSARecvMsg == NULL) {
 		GUID guid = WSAID_WSARECVMSG;
 		DWORD bytes_returned;
@@ -268,13 +282,13 @@ static ortp_socket_t create_and_bind(const char *addr, int *port, int *sock_fami
 			err=getsockname(sock,(struct sockaddr*)&saddr,&slen);
 			if (err==-1){
 				ortp_error("getsockname(): %s",getSocketError());
-				close(sock);
+				close_socket(sock);
 				return (ortp_socket_t)-1;
 			}
 			err=getnameinfo((struct sockaddr*)&saddr, slen, NULL, 0, num, sizeof(num), NI_NUMERICHOST | NI_NUMERICSERV);
 			if (err!=0){
 				ortp_error("getnameinfo(): %s",gai_strerror(err));
-				close(sock);
+				close_socket(sock);
 				return (ortp_socket_t)-1;
 			}
 			*port=atoi(num);
@@ -284,7 +298,7 @@ static ortp_socket_t create_and_bind(const char *addr, int *port, int *sock_fami
 	return sock;
 }
 
-static void set_socket_sizes(int sock, unsigned int sndbufsz, unsigned int rcvbufsz){
+static void set_socket_sizes(ortp_socket_t sock, unsigned int sndbufsz, unsigned int rcvbufsz){
 	int err;
 	bool_t done=FALSE;
 	if (sndbufsz>0){
@@ -330,7 +344,7 @@ static void set_socket_sizes(int sock, unsigned int sndbufsz, unsigned int rcvbu
  *	In case where the rtp session is send-only, then it is not required to call this function:
  *	when calling rtp_session_set_remote_addr(), if no local address has been set, then the
  *	default INADRR_ANY (0.0.0.0) IP address with a random port will be used. Calling
- *	rtp_sesession_set_local_addr() is mandatory when the session is recv-only or duplex.
+ *	rtp_session_set_local_addr() is mandatory when the session is recv-only or duplex.
  *
  *	Returns: 0 on success.
 **/
@@ -342,7 +356,7 @@ rtp_session_set_local_addr (RtpSession * session, const char * addr, int rtp_por
 	int sockfamily;
 	if (session->rtp.gs.socket!=(ortp_socket_t)-1){
 		/* don't rebind, but close before*/
-		rtp_session_release_sockets(session);
+		_rtp_session_release_sockets(session, FALSE);
 	}
 	/* try to bind the rtp port */
 
@@ -374,6 +388,35 @@ rtp_session_set_local_addr (RtpSession * session, const char * addr, int rtp_por
 	return -1;
 }
 
+static void _rtp_session_recreate_sockets(RtpSession *session){
+	char addr[NI_MAXHOST];
+	int err = getnameinfo((struct sockaddr*)&session->rtp.gs.loc_addr, session->rtp.gs.loc_addrlen, addr, sizeof(addr), NULL, 0, NI_NUMERICHOST);
+	if (err != 0){
+		ortp_error("_rtp_session_recreate_sockets(): getnameinfo() error: %s", gai_strerror(err));
+		return;
+	}
+	/*re create and bind sockets as they were done previously*/
+	ortp_message("RtpSession %p is going to re-create its socket.", session);
+	rtp_session_set_local_addr(session, addr, session->rtp.gs.loc_port, session->rtcp.gs.loc_port);
+}
+
+static void _rtp_session_check_socket_refresh(RtpSession *session){
+	if (session->flags & RTP_SESSION_SOCKET_REFRESH_REQUESTED){
+		session->flags &= ~RTP_SESSION_SOCKET_REFRESH_REQUESTED;
+		_rtp_session_recreate_sockets(session);
+	}
+}
+
+/**
+ * Requests the session to re-create and bind its RTP and RTCP sockets same as they are currently.
+ * This is used when a change in the routing rules of the host or process was made, in order to have
+ * this routing rules change taking effect on the RTP/RTCP packets sent by the session.
+**/
+void rtp_session_refresh_sockets(RtpSession *session){
+	if (session->rtp.gs.socket != (ortp_socket_t) -1){
+		session->flags |= RTP_SESSION_SOCKET_REFRESH_REQUESTED;
+	}
+}
 
 int rtp_session_join_multicast_group(RtpSession *session, const char *ip){
 	int err;
@@ -400,7 +443,7 @@ int rtp_session_set_pktinfo(RtpSession *session, int activate)
 {
 	int retval;
 	int optname;
-#if defined(WIN32) || defined(_WIN32_WCE)
+#if defined(_WIN32) || defined(_WIN32_WCE)
 	char optval[sizeof(DWORD)];
 	int optlen = sizeof(optval);
 #else
@@ -411,7 +454,7 @@ int rtp_session_set_pktinfo(RtpSession *session, int activate)
 	// Dont't do anything if socket hasn't been created yet
 	if (session->rtp.gs.socket == (ortp_socket_t)-1) return 0;
 
-#if defined(WIN32) || defined(_WIN32_WCE)
+#if defined(_WIN32) || defined(_WIN32_WCE)
 	memset(optval, activate, sizeof(optval));
 #endif
 
@@ -599,7 +642,7 @@ int rtp_session_set_dscp(RtpSession *session, int dscp){
 	int tos;
 	int proto;
 	int value_type;
-#if (_WIN32_WINNT >= 0x0600)
+#if (_WIN32_WINNT >= 0x0600) && defined(ORTP_WINDOWS_DESKTOP)
 	OSVERSIONINFOEX ovi;
 #endif
 
@@ -609,7 +652,7 @@ int rtp_session_set_dscp(RtpSession *session, int dscp){
 	// Don't do anything if socket hasn't been created yet
 	if (session->rtp.gs.socket == (ortp_socket_t)-1) return 0;
 
-#if (_WIN32_WINNT >= 0x0600) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#if (_WIN32_WINNT >= 0x0600) && defined(ORTP_WINDOWS_DESKTOP)
 	memset(&ovi, 0, sizeof(ovi));
 	ovi.dwOSVersionInfoSize = sizeof(ovi);
 	GetVersionEx((LPOSVERSIONINFO) & ovi);
@@ -695,7 +738,7 @@ int rtp_session_set_dscp(RtpSession *session, int dscp){
 				ortp_error("Fail to set DSCP value on rtcp socket: %s",getSocketError());
 			}
 		}
-#if (_WIN32_WINNT >= 0x0600) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#if (_WIN32_WINNT >= 0x0600) && defined(ORTP_WINDOWS_DESKTOP)
 	}
 #endif
 	return retval;
@@ -828,7 +871,7 @@ _rtp_session_set_remote_addr_full (RtpSession * session, const char * rtp_addr,
 		/* set a destination address that has the same type as the local address */
 		if (res->ai_family==session->rtp.gs.sockfamily ) {
 			memcpy(rtp_saddr, res->ai_addr, res->ai_addrlen);
-			*rtp_saddr_len=res->ai_addrlen;
+			*rtp_saddr_len=(socklen_t)res->ai_addrlen;
 			err=0;
 			break;
 		}
@@ -858,7 +901,7 @@ _rtp_session_set_remote_addr_full (RtpSession * session, const char * rtp_addr,
 		if (res->ai_family==session->rtp.gs.sockfamily ) {
 			err=0;
 			memcpy(rtcp_saddr, res->ai_addr, res->ai_addrlen);
-			*rtcp_saddr_len=res->ai_addrlen;
+			*rtcp_saddr_len=(socklen_t)res->ai_addrlen;
 			break;
 		}
 	}
@@ -1025,9 +1068,10 @@ int _ortp_sendto(ortp_socket_t sockfd, mblk_t *m, int flags, const struct sockad
 int _rtp_session_sendto(RtpSession *session, bool_t is_rtp, mblk_t *m, int flags, const struct sockaddr *destaddr, socklen_t destlen){
 	int ret;
 
+	_rtp_session_check_socket_refresh(session);
 	if (session->net_sim_ctx && (session->net_sim_ctx->params.mode==OrtpNetworkSimulatorOutbound
 			|| session->net_sim_ctx->params.mode==OrtpNetworkSimulatorOutboundControlled)){
-		ret=msgdsize(m);
+		ret=(int)msgdsize(m);
 		m=dupmsg(m);
 		memcpy(&m->net_addr,destaddr,destlen);
 		m->net_addrlen=destlen;
@@ -1079,7 +1123,7 @@ static int rtp_session_rtp_sendto(RtpSession * session, mblk_t * m, struct socka
 		/*errors to auxiliary destinations are not notified*/
 		if (error < 0){
 			if (session->on_network_error.count>0){
-				rtp_signal_table_emit3(&session->on_network_error,(long)"Error sending RTP packet",INT_TO_POINTER(getSocketErrorCode()));
+				rtp_signal_table_emit3(&session->on_network_error,"Error sending RTP packet",ORTP_INT_TO_POINTER(getSocketErrorCode()));
 			}else log_send_error(session,"rtp",m,destaddr,destlen);
 			session->rtp.send_errno=getSocketErrorCode();
 		}else{
@@ -1137,7 +1181,7 @@ static int rtp_session_rtcp_sendto(RtpSession * session, mblk_t * m, struct sock
 	if (!is_aux){
 		if (error < 0){
 			if (session->on_network_error.count>0){
-				rtp_signal_table_emit3(&session->on_network_error,(long)"Error sending RTCP packet",INT_TO_POINTER(getSocketErrorCode()));
+				rtp_signal_table_emit3(&session->on_network_error,"Error sending RTCP packet",ORTP_INT_TO_POINTER(getSocketErrorCode()));
 			}else{
 				log_send_error(session,"rtcp",m,destaddr,destlen);
 			}
@@ -1302,7 +1346,7 @@ static void compute_rtt(RtpSession *session, const struct timeval *now, uint32_t
 		if (rtt_frac>=0){
 			rtt_frac/=65536.0;
 
-			session->rtt=rtt_frac;
+			session->rtt=(float)rtt_frac;
 			/*ortp_message("rtt estimated to %f s",session->rtt);*/
 		}else ortp_warning("Negative RTT computation, maybe due to clock adjustments.");
 	}
@@ -1410,7 +1454,7 @@ static int process_rtcp_packet( RtpSession *session, mblk_t *block, struct socka
 		return 0;
 	}
 
-	update_recv_bytes(&session->rtcp.gs, block->b_wptr - block->b_rptr);
+	update_recv_bytes(&session->rtcp.gs, (int)(block->b_wptr - block->b_rptr));
 
 	/* compound rtcp packet can be composed by more than one rtcp message */
 	do{
@@ -1490,7 +1534,7 @@ static void rtp_process_incoming_packet(RtpSession * session, mblk_t * mp, bool_
 			}
 		}
 		/* then parse the message and put on jitter buffer queue */
-		update_recv_bytes(&session->rtp.gs, mp->b_wptr - mp->b_rptr);
+		update_recv_bytes(&session->rtp.gs, (int)(mp->b_wptr - mp->b_rptr));
 		rtp_session_rtp_parse(session, mp, user_ts, remaddr,addrlen);
 		/*for bandwidth measurements:*/
 	}else {
@@ -1564,7 +1608,7 @@ int rtp_session_rtp_recv (RtpSession * session, uint32_t user_ts) {
 			if (error==-1 && !is_would_block_error((errnum=getSocketErrorCode())) )
 			{
 				if (session->on_network_error.count>0){
-					rtp_signal_table_emit3(&session->on_network_error,(long)"Error receiving RTP packet",INT_TO_POINTER(getSocketErrorCode()));
+					rtp_signal_table_emit3(&session->on_network_error,"Error receiving RTP packet",ORTP_INT_TO_POINTER(getSocketErrorCode()));
 				}else ortp_warning("Error receiving RTP packet: %s, err num  [%i],error [%i]",getSocketError(),errnum,error);
 #ifdef __ios
 				/*hack for iOS and non-working socket because of background mode*/
@@ -1641,7 +1685,7 @@ int rtp_session_rtcp_recv (RtpSession * session) {
 			if (error==-1 && !is_would_block_error((errnum=getSocketErrorCode())) )
 			{
 				if (session->on_network_error.count>0){
-					rtp_signal_table_emit3(&session->on_network_error,(long)"Error receiving RTCP packet",INT_TO_POINTER(getSocketErrorCode()));
+					rtp_signal_table_emit3(&session->on_network_error,"Error receiving RTCP packet",ORTP_INT_TO_POINTER(getSocketErrorCode()));
 				}else ortp_warning("Error receiving RTCP packet: %s, err num  [%i],error [%i]",getSocketError(),errnum,error);
 #ifdef __ios
 				/*hack for iOS and non-working socket because of background mode*/
