@@ -33,14 +33,7 @@ void qinit(queue_t *q){
 
 void mblk_init(mblk_t *mp)
 {
-	mp->b_cont=mp->b_prev=mp->b_next=NULL;
-	mp->b_rptr=mp->b_wptr=NULL;
-	mp->reserved1=0;
-	mp->reserved2=0;
-#if defined(ORTP_TIMESTAMP)
-	memset(&(mp->timestamp), 0, sizeof(struct timeval));
-#endif
-	mp->ttl_or_hl = 0;
+	memset(mp, 0, sizeof(mblk_t));
 }
 
 void mblk_meta_copy(const mblk_t *source, mblk_t *dest) {
@@ -82,8 +75,7 @@ mblk_t *allocb(size_t size, int pri)
 	mblk_t *mp;
 	dblk_t *datab;
 
-	mp=(mblk_t *) ortp_malloc(sizeof(mblk_t));
-	mblk_init(mp);
+	mp=(mblk_t *) ortp_malloc0(sizeof(mblk_t));
 	datab=datab_alloc(size);
 
 	mp->b_datap=datab;
@@ -97,11 +89,9 @@ mblk_t *esballoc(uint8_t *buf, size_t size, int pri, void (*freefn)(void*) )
 	mblk_t *mp;
 	dblk_t *datab;
 
-	mp=(mblk_t *) ortp_malloc(sizeof(mblk_t));
-	mblk_init(mp);
+	mp=(mblk_t *) ortp_malloc0(sizeof(mblk_t));
 	datab=(dblk_t *) ortp_malloc(sizeof(dblk_t));
 
-
 	datab->db_base=buf;
 	datab->db_lim=buf+size;
 	datab->db_ref=1;
@@ -142,8 +132,7 @@ mblk_t *dupb(mblk_t *mp)
 	return_val_if_fail(mp->b_datap->db_base!=NULL,NULL);
 
 	datab_ref(mp->b_datap);
-	newm=(mblk_t *) ortp_malloc(sizeof(mblk_t));
-	mblk_init(newm);
+	newm=(mblk_t *) ortp_malloc0(sizeof(mblk_t));
 	mblk_meta_copy(mp, newm);
 	newm->b_datap=mp->b_datap;
 	newm->b_rptr=mp->b_rptr;
@@ -242,15 +231,15 @@ void msgpullup(mblk_t *mp,size_t len)
 {
 	mblk_t *firstm=mp;
 	dblk_t *db;
-	int wlen=0;
+	size_t wlen=0;
 
 	if (mp->b_cont==NULL && len==-1) return;	/*nothing to do, message is not fragmented */
 
 	if (len==-1) len=msgdsize(mp);
 	db=datab_alloc(len);
 	while(wlen<len && mp!=NULL){
-		int remain=len-wlen;
-		int mlen=mp->b_wptr-mp->b_rptr;
+		int remain=(int)(len-wlen);
+		int mlen=(int)(mp->b_wptr-mp->b_rptr);
 		if (mlen<=remain){
 			memcpy(&db->db_base[wlen],mp->b_rptr,mlen);
 			wlen+=mlen;
@@ -298,7 +287,7 @@ mblk_t * appendb(mblk_t *mp, const char *data, size_t size, bool_t pad){
 	size_t padcnt=0;
 	size_t i;
 	if (pad){
-		padcnt= (size_t)(4L-( (long)(((long)mp->b_wptr)+size) % 4L)) % 4L;
+		padcnt = (size_t)(4 - ((((intptr_t)mp->b_wptr) + size) % 4)) % 4;
 	}
 	if ((mp->b_wptr + size +padcnt) > mp->b_datap->db_lim){
 		/* buffer is not large enough: append a new block (with the same size ?)*/
@@ -337,7 +326,7 @@ mblk_t *msgb_allocator_alloc(msgb_allocator_t *a, size_t size){
 
 	/*lookup for an unused msgb (data block with ref count ==1)*/
 	for(m=qbegin(q);!qend(q,m);m=qnext(q,m)){
-		if (m->b_datap->db_ref==1 && m->b_datap->db_lim-m->b_datap->db_base>=size){
+		if ((m->b_datap->db_ref == 1) && ((size_t)(m->b_datap->db_lim - m->b_datap->db_base) >= size)){
 			found=m;
 			break;
 		}
