@@ -43,7 +43,7 @@ static char *help="usage: test_tevrecv	filename loc_port\n";
 
 int dtmf_count=0;
 
-void recv_tev_cb(RtpSession *session,int type,long user_data)
+void recv_tev_cb(RtpSession *session,unsigned long type, unsigned long dummy, void* user_data)
 {
 	printf("Receiving telephony event:%i\n",type);
 	if (type<16) printf("This is dtmf %c\n",dtmf_tab[type]);
@@ -53,14 +53,14 @@ void recv_tev_cb(RtpSession *session,int type,long user_data)
 int main(int argc, char *argv[])
 {
 	RtpSession *session;
-	char buffer[160];
+	unsigned char buffer[160];
 	int err;
 	FILE *outfile;
 	uint32_t ts=0;
 	int have_more;
 
 	if (argc<3){
-		printf(help);
+		printf("%s",help);
 		return -1;
 	}
 
@@ -74,7 +74,7 @@ int main(int argc, char *argv[])
 	
 	rtp_session_set_scheduling_mode(session,1);
 	rtp_session_set_blocking_mode(session,1);
-	rtp_session_set_local_addr(session,"0.0.0.0",atoi(argv[2]));
+	rtp_session_set_local_addr(session,"0.0.0.0",atoi(argv[2]),-1);
 	rtp_session_set_payload_type(session,0);
 	
 	/* register for telephony events */
